@@ -2,6 +2,7 @@ import logging
 from dotenv import load_dotenv
 import os
 import pytest
+
 from cc_clients_python_lib.flink_client import FlinkClient, FLINK_CONFIG, StatementPhase
 from cc_clients_python_lib.http_status import HttpStatus
 
@@ -19,6 +20,7 @@ logger.setLevel(logging.INFO)
 
 # Initialize the global variables.
 config = {}
+principal_id = ""
 statement_name = ""
 catalog_name = ""
 database_name = ""
@@ -52,11 +54,15 @@ def load_configurations():
     catalog_name = os.getenv("FLINK_CATALOG_NAME")
     database_name = os.getenv("FLINK_DATABASE_NAME")
 
+    # Set the Flink SQL security principal ID.
+    global principal_id
+    principal_id = os.getenv("PRINCIPAL_ID")
+
 
 def test_delete_statement():
     """Test the delete_statement() function."""
 
-    # Instantiate the FlinkClient classs.
+    # Instantiate the FlinkClient class.
     flink_client = FlinkClient(config)
 
     http_status_code, response = flink_client.delete_statement(statement_name)
@@ -71,7 +77,7 @@ def test_delete_statement():
 def test_delete_statements_by_phase():
     """Test the delete_statements_by_phase() function."""
 
-    # Instantiate the FlinkClient classs.
+    # Instantiate the FlinkClient class.
     flink_client = FlinkClient(config)
 
     http_status_code, error_message = flink_client.delete_statements_by_phase(StatementPhase.COMPLETED)
@@ -86,7 +92,7 @@ def test_delete_statements_by_phase():
 def test_get_statement_list():
     """Test the get_statement_list() function."""
 
-    # Instantiate the FlinkClient classs.
+    # Instantiate the FlinkClient class.
     flink_client = FlinkClient(config)
 
     http_status_code, _, response = flink_client.get_statement_list()
@@ -104,7 +110,7 @@ def test_get_statement_list():
 def test_submit_statement():
     """Test the submit_statement() function."""
 
-    # Instantiate the FlinkClient classs.
+    # Instantiate the FlinkClient class.
     flink_client = FlinkClient(config)
 
     http_status_code, error_message, response = flink_client.submit_statement("drop-statement",
@@ -122,7 +128,7 @@ def test_submit_statement():
 def test_get_compute_pool_list():
     """Test the get_compute_pool() function."""
 
-    # Instantiate the FlinkClient classs.
+    # Instantiate the FlinkClient class.
     flink_client = FlinkClient(config)
 
     http_status_code, error_message, response = flink_client.get_compute_pool_list()
@@ -140,7 +146,7 @@ def test_get_compute_pool_list():
 def test_get_compute_pool():
     """Test the get_compute_pool() function."""
 
-    # Instantiate the FlinkClient classs.
+    # Instantiate the FlinkClient class.
     flink_client = FlinkClient(config)
 
     http_status_code, error_message, response = flink_client.get_compute_pool()
@@ -154,9 +160,9 @@ def test_get_compute_pool():
 
 
 def test_stop_statement():
-    """Test the pause_statement() function."""
+    """Test the stop_statement() function."""
 
-    # Instantiate the FlinkClient classs.
+    # Instantiate the FlinkClient class.
     flink_client = FlinkClient(config)
 
     http_status_code, response = flink_client.stop_statement(statement_name, True)
@@ -166,3 +172,35 @@ def test_stop_statement():
     except AssertionError as e:
         logger.error(e)
         logger.error("Response: %s", response)
+
+
+def test_update_statement():
+    """Test the update_statement() function."""
+
+    # Instantiate the FlinkClient class.
+    flink_client = FlinkClient(config)
+
+    http_status_code, response = flink_client.update_statement(statement_name, False, new_security_principal_id=principal_id)
+ 
+    try:
+        assert http_status_code == HttpStatus.OK, f"HTTP Status Code: {http_status_code}"
+        logger.info("Response: %s", response)
+    except AssertionError as e:
+        logger.error(e)
+        logger.error("Response: %s", response)
+
+
+def test_update_all_statements():
+    """Test the update_all_statements() function."""
+
+    # Instantiate the FlinkClient class.
+    flink_client = FlinkClient(config)
+
+    http_status_code, response = flink_client.update_all_statements(True, new_security_principal_id=principal_id)
+ 
+    try:
+        assert http_status_code == HttpStatus.OK, f"HTTP Status Code: {http_status_code}"
+        logger.info("Response: %s", response)
+    except AssertionError as e:
+        logger.error(e)
+        logger.error("Response: %s", response)
